CustomTextField class
A reusable custom text field widget.
Supports validation, icons, and custom styling.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- CustomTextField
Constructors
-
CustomTextField({Key? key, TextEditingController? controller, int? maxlines, int? maxLength, String? label, String? labelAbove, bool? readOnly, TextInputType? textInputType, bool isObscureText = false, String? hintText, List<
TextInputFormatter> ? inputFormatters, TextStyle? hintTextStyle, OutlineInputBorder? enabledBorder, Widget? suffixIcon, Widget? prefixIcon, String? validator(String?)?, dynamic onChanged(String)?, Color? fillColor, VoidCallback? onTap, String? errorMessage}) -
Creates a CustomTextField.
const
Properties
- controller → TextEditingController?
-
Controls the text being edited.
final
- enabledBorder → OutlineInputBorder?
-
Border when the field is enabled.
final
- errorMessage → String?
-
final
- fillColor → Color?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- hintText → String?
-
Placeholder text displayed inside the field.
final
- hintTextStyle → TextStyle?
-
final
-
inputFormatters
→ List<
TextInputFormatter> ? -
final
- isObscureText → bool
-
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- label → String?
-
final
- labelAbove → String?
-
final
- maxLength → int?
-
final
- maxlines → int?
-
final
- onChanged → dynamic Function(String)?
-
final
- onTap → VoidCallback?
-
final
- prefixIcon → Widget?
-
final
- readOnly → bool?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- suffixIcon → Widget?
-
final
- textInputType → TextInputType?
-
final
- validator → String? Function(String?)?
-
final
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< CustomTextField> -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited